@@ -14,7 +14,7 @@
 //
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #include <assert.h>
 #include <time.h>
@@ -1003,7 +1003,7 @@ void KDat::setTapePresent( bool tapePresent, bool eject )
                     KMessageBox::sorry( this, i18n( "This tape has not been formatted by KDat." ));
                 } else {
                     int result = KMessageBox::questionYesNo( this,
-                          i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ));
+                          i18n( "This tape has not been formatted by KDat.\n\nWould you like to format it now?" ), QString::null, i18n("Format"), i18n("Do Not Format"));
                     if (result == KMessageBox::Yes) {
                         fileFormatTape();
                         return;
