@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -80,12 +80,16 @@ DEB::~DEB()
 // check if debian file
 bool DEB::isType(char *buf, const QString &)
 {
-  if  (!strcmp(buf,"!<arch>\n")) {
-    return true;
-  } else if (!strncmp(buf,"0.9",3)) {
-    return true;
-  } else
+  if (hasProgram) {
+    if  (!strcmp(buf,"!<arch>\n")) {
+      return true;
+    } else if (!strncmp(buf,"0.9",3)) {
+      return true;
+    } else
+      return false;
+  } else {
     return false;
+  }
 }
 
 void DEB::distPackages(QPtrList<packageInfo> *, cacheObj *)
@@ -171,7 +175,7 @@ void DEB::listPackList(QPtrList<packageInfo> *pki, const QString &fname, cacheOb
 	  if (!p->pkgInsert(pki, typeID, cp == 0)) {
 	    delete p;
 	  } else if (cp) {
-	    p->info->insert("base",new QString(cp->base));
+	    p->info.insert("base", cp->base);
 	  }
 	}
 	list.clear();
@@ -303,8 +307,7 @@ packageInfo *DEB::collectInfo(QStringList &ln, pkgInterface *pkgInt)
     pkgInt = this;
   }
 
-  QDict<QString> *a = new QDict<QString>;
-  a->setAutoDelete(TRUE);
+  QMap<QString, QString> a;
 
   QString key, val;
   bool bad_install = FALSE;
@@ -330,29 +333,28 @@ packageInfo *DEB::collectInfo(QStringList &ln, pkgInterface *pkgInt)
 	}
       }
     } else if (key == "description") {
-      a->insert("summary", new QString(val));
+      a.insert("summary", val);
       QString desc;
       while (++it != ln.end()) {
 	if ((*it)[0] == ' ') {
 	  desc += *it;
 	} else {
-	  a->insert("description", new QString(desc));
+	  a.insert("description", desc);
 	  goto loop;
 	}
       }
-      a->insert("description", new QString(desc));
+      a.insert("description", desc);
       break;
     } else if (key == "package") {
-      a->insert("name", new QString(val));
+      a.insert("name", val);
       haveName = TRUE;
     } else if (key == "md5sum") {
       available = TRUE;
       bad_install = FALSE;
     } else if (key == "section") {
-      a->insert("group",  new QString(val));
+      a.insert("group",  val);
     } else if (key == "status") {
       if ((val.find("not-installed")  >= 0) || (val.find("config-files") >= 0)) {
-	delete a;
 	return 0;
       }
       if (val != "install ok installed" &&
@@ -361,15 +363,15 @@ packageInfo *DEB::collectInfo(QStringList &ln, pkgInterface *pkgInt)
 	  val != "purge ok installed") {
 	bad_install = TRUE;
       }
-      a->insert("status",  new QString(val));
+      a.insert("status", val);
     } else if (key == "version") {
-      a->insert("version",  new QString(val));
+      a.insert("version", val);
     } else if (key == "size") {
-      a->insert("file-size",  new QString(val));
+      a.insert("file-size", val);
     } else if (key == "installed-size") {
-      a->insert("size",  new QString(val + "000"));
+      a.insert("size",  val + "000");
     } else {
-       a->insert(key, new QString(val));
+       a.insert(key, val);
     }
     //    kdDebug() << "C=" << key << "," << val <<"\n";
   }
@@ -386,7 +388,6 @@ packageInfo *DEB::collectInfo(QStringList &ln, pkgInterface *pkgInt)
     i->fixup();
     return i;
   } else {
-    delete a;
     return 0;
   }
 }
@@ -477,7 +478,7 @@ QStringList DEB::getIFileList(packageInfo *p)
 }
 
 // query an uninstalled package
-QStringList DEB::getUFileList(QString fn)
+QStringList DEB::getUFileList(const QString &fn)
 {
   QString s = "dpkg --contents ";
   s += "'";
@@ -578,7 +579,7 @@ QString DEB::install(int installFlags, QPtrList<packageInfo> *p,
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-QString DEB::doInstall(int installFlags, QString packs, bool &test)
+QString DEB::doInstall(int installFlags, const QString &packs, bool &test)
 {
   QString s = "dpkg -i ";
   s += setOptions(installFlags, paramsInst);
