@@ -16,8 +16,8 @@
 **
 ** You should have received a copy of the GNU General Public License
 ** along with this program in a file called COPYING; if not, write to
-** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-** MA 02111-1307, USA.
+** the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+** MA 02110-1301, USA.
 */
 
 /*
@@ -376,7 +376,7 @@ void KpTreeList::packageHighlighted(QListViewItem *item, packageDisplayWidget *p
   notPress = false;
 }
 
-KpTreeListItem *KpTreeList::search(QString str, QString head,
+KpTreeListItem *KpTreeList::search(const QString &str, const QString &head,
 				KpTreeListItem  *start)
 {
   KpTreeListItem  *item = firstChild();
@@ -397,7 +397,7 @@ KpTreeListItem *KpTreeList::search(QString str, QString head,
   return 0;
 }
 
-KpTreeListItem *KpTreeList::search(QString str, bool subStr, bool wrap,
+KpTreeListItem *KpTreeList::search(const QString &str, bool subStr, bool wrap,
 			     bool start=FALSE)
 {
   if (!firstChild())
@@ -647,7 +647,7 @@ void KpTreeListItem::show()
 
 int KpTreeListItem::compare( QListViewItem *i, int col, bool ascending ) const
 { // Make sorting more certain
-  if (col == 2) { // size column
+  if (col == 3) { // size column
     QString k, j;
 
     j = key( col, ascending );
