@@ -1,6 +1,4 @@
  /***************************************************************************
-                          main.cpp  -  description
-                             -------------------
     copyright            : (C) 1997-2000 by Peter Putzer
     email                : putzer@kde.org
  ***************************************************************************/
