@@ -12,18 +12,19 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #include "delUser.h"
 
 #include <qlabel.h>
 #include <qvbox.h>
+#include <qfile.h>
 
 #include <klocale.h>
 
-delUser::delUser(KUser *AUser, QWidget *parent, const char *name) 
+delUser::delUser(KU::KUser *AUser, QWidget *parent, const char *name) 
  : KDialogBase( parent, name, true, i18n("Delete User"),
                 KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
 {                   
@@ -32,9 +33,9 @@ delUser::delUser(KUser *AUser, QWidget *parent, const char *name)
                    "<p>Also perform the following actions:").arg(AUser->getName()),
               page);
   m_deleteHomeDir = new QCheckBox(i18n("Delete &home folder: %1").arg(AUser->getHomeDir()), page);
-  QString mailboxpath = QString::fromLatin1("%1/%2").arg(QString::fromLatin1(MAIL_SPOOL_DIR)).arg(AUser->getName());
+  QString mailboxpath = QFile::decodeName(MAIL_SPOOL_DIR) + "/" + AUser->getName();
   m_deleteMailBox = new QCheckBox(i18n("Delete &mailbox: %1").arg(mailboxpath), page);
-  setButtonGuiItem(KDialogBase::Ok, KGuiItem(i18n("&Delete"), QString::fromLatin1("editdelete")) );
+  setButtonGuiItem(KDialogBase::Ok, KStdGuiItem::del());
 }
 
 #include "delUser.moc"
